% -----------------------------------------------------------
% Journal class - version 2.0 (September 1999-September 2002)
% -----------------------------------------------------------
% copyright (c) 1999-2002 by Martin Decky

\NeedsTeXFormat{LaTeX2e}
 
\ProvidesClass{Journal}[1999/07/01 LaTeX class]

\usepackage[T1]{fontenc}
\usepackage[latin2]{inputenc} 

\language=1

% Adobe Type 1 Times-Roman fonts (PDF standard):

\DeclareFontFamily{T1}{ptm}{}
\DeclareFontShape{T1}{ptm}{m}{n}{<-> ptmr8t}{}
\DeclareFontShape{T1}{ptm}{m}{sc}{<-> ptmrc8t}{}
\DeclareFontShape{T1}{ptm}{m}{it}{<-> ptmri8t}{}
\DeclareFontShape{T1}{ptm}{b}{n}{<-> ptmb8t}{}
\DeclareFontShape{T1}{ptm}{b}{sc}{<-> ptmbc8t}{}
\DeclareFontShape{T1}{ptm}{b}{it}{<-> ptmbi8t}{}

% Adobe Type 1 Courier fonts (PDF standard):

\DeclareFontFamily{T1}{pcr}{}
\DeclareFontShape{T1}{pcr}{m}{n}{<-> pcrr8t}{}
\DeclareFontShape{T1}{pcr}{m}{sc}{<-> pcrrc8t}{}
\DeclareFontShape{T1}{pcr}{m}{it}{<-> pcrri8t}{}
\DeclareFontShape{T1}{pcr}{b}{n}{<-> pcrb8t}{}
\DeclareFontShape{T1}{pcr}{b}{sc}{<-> pcrbc8t}{}
\DeclareFontShape{T1}{pcr}{b}{it}{<-> pcrbi8t}{}
\DeclareFontShape{T1}{pcr}{bx}{n}{<-> pcrb8t}{}

% Adobe Type 1 Helvetica fonts (PDF standard):

\DeclareFontFamily{T1}{phv}{}
\DeclareFontShape{T1}{phv}{m}{n}{<-> phvr8t}{}
\DeclareFontShape{T1}{phv}{m}{sc}{<-> phvc8t}{}
\DeclareFontShape{T1}{phv}{m}{it}{<-> phvro8t}{}
\DeclareFontShape{T1}{phv}{b}{n}{<-> phvb8t}{}
\DeclareFontShape{T1}{phv}{b}{sc}{<-> phvbc8t}{}
\DeclareFontShape{T1}{phv}{b}{it}{<-> phvbo8t}{}

% The AmsLaTeX 2e logo

\def\AmSLaTeXe{\AmS-\LaTeXe}

% Switch off some of the article options.
 
\DeclareOption{a4paper}{\OptionNotUsed}
\DeclareOption{a5paper}{\OptionNotUsed}
\DeclareOption{b5paper}{\OptionNotUsed}
\DeclareOption{letterpaper}{\OptionNotUsed}
\DeclareOption{legalpaper}{\OptionNotUsed}
\DeclareOption{executivepaper}{\OptionNotUsed}
\DeclareOption{landscape}{\OptionNotUsed}
\DeclareOption{oneside}{\OptionNotUsed}
\DeclareOption{titlepage}{\OptionNotUsed}

% The text size, option 'a5size'

\newif\if@afive
\@afivefalse
\DeclareOption{a5size}{\@afivetrue}

% Use Type 1 fonts if option 'type1' declared

\DeclareOption{type1}{%
  \renewcommand{\rmdefault}{ptm}%
  \renewcommand{\ttdefault}{pcr}%
  \renewcommand{\sfdefault}{phv}%
  \renewcommand{\bfdefault}{b}%
  \renewcommand{\itdefault}{it}%
  \renewcommand{\sldefault}{it}%
  \renewcommand{\scdefault}{sc}%
}

% Font aliases

\newcommand{\@asectionfont}{\normalfont\Huge}
\newcommand{\@indiciafont}{\normalfont\footnotesize}
\newcommand{\@headingfont}{\Large\sffamily\slshape}
\newcommand{\@subheadingfont}{\normalsize\sffamily\bfseries}

% The default action for any option is to pass it to the article
% class.
 
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
 
% Execute the options.
 
\ProcessOptions
 
% Load the article class.
 
\LoadClass[onecolumn,twoside]{article}

% The page style.

\setlength\paperheight   {297mm}%
\setlength\paperwidth    {210mm}%
\setlength\textheight    {260mm}%
\setlength\textwidth     {180mm}%
\setlength\topmargin     {-20mm}%
\setlength\evensidemargin {-10mm}%
\setlength\oddsidemargin {-10mm}%

% A5 wide style

\if@afive
    \setlength\paperheight   {210mm}%
    \setlength\paperwidth    {148mm}%
    \setlength\textheight    {200mm}%
    \setlength\textwidth     {135mm}%
    \setlength\topmargin     {-5mm}%
    \setlength\evensidemargin {+27.5mm}%
    \setlength\oddsidemargin {+27.5mm}%
\fi

% Header and footer

\usepackage{fancyhdr} 
\pagestyle{fancy}

\renewcommand{\sectionmark}[1]{\markboth{#1}{#1}}

\newcounter{nsection}
\setlength{\unitlength}{10mm}
\newcommand{\blob}{\rule[-,\unitlength]{\unitlength}{\unitlength}}

\cfoot{\thepage}
\renewcommand{\headrulewidth}{0.4pt}
\renewcommand{\footrulewidth}{0.4pt}
\fancyhead[RO]{\@pubauthor}
\fancyhead[LO]{\@title}
\fancyhead[LE]{\@pubtitle}
\fancyhead[RE]{\@title}
 
\setlength{\parindent}{1em}
\setlength{\parfillskip}{0pt plus 2\textwidth}

% Graphics, AmsLaTeX, Multicolumn & Longtable packages

\usepackage{color}
\usepackage{graphics}
\usepackage{amsmath}
\usepackage{amssymb}
\usepackage{multicol}
\usepackage{longtable}
\usepackage{floatflt}

% Allow very long longtables

\setcounter{LTchunksize}{1000}

% Supply more strict multicolumning

\premulticols = 0.2\textheight
\multicoltolerance = 2000
\c@collectmore = -1

% image captioning

\long\def\@makecaption#1#2{%
  \sbox\@tempboxa{\textcolor[rgb]{1,0.21,0.21}{$\m@th\blacksquare$}~\textbf{#2}}%
  \ifdim \wd\@tempboxa >\hsize
    \textcolor[rgb]{1,0.21,0.21}{$\m@th\blacksquare$}~\textbf{#2}\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}
 
% \maketitle parameters.

\newcommand{\pubtitle}{\newcommand{\@pubtitle}}
\newcommand{\pubauthor}{\newcommand{\@pubauthor}}

% Create the titlepage
 
\renewcommand{\maketitle}{%
  \begin{titlepage}
   \null\vfil
   \begin{center}
    \Huge{\textbf{\@title}}\\
    \Large{\@pubtitle}
   \end{center}
   \vfil\null
   \begin{center}
    \Large{\@pubauthor}
   \end{center}
  \end{titlepage}      
}

% Supress header and footer in titlepage
 
\newcommand{\ps@titlepage}{%
   \renewcommand{\@oddhead}{\hfill}%
   \renewcommand{\@evenhead}{\hfill}%
}

\newcommand{\makecontents}[1]{
 \begin{center}
  \@asectionfont{Obsah}
 \end{center}
 \@mkboth{Obsah}{Obsah}
 \begin{multicols}{2}
  \@starttoc{toc}
 \end{multicols} 
 \vfill\null
 \framebox{\parbox{0.98\textwidth}{#1}}
 \pagebreak
}

\newcommand{\makefinal}[1]{
 \null\vfill
 \parbox{\textwidth}{\textbf{#1}}
}

% Sectioning commands 

\renewcommand{\subsubsection}[1]{%
   \@startsection
      {subsubsection}{3}{\z@}{-1.5ex \@plus -1ex \@minus -.2ex}%
      {1ex \@plus.2ex}{\@subheadingfont}{#1}%
   \nopagebreak        
}

\renewcommand{\subsection}[1]{%
   \@startsection
      {subsection}{2}{\z@}{-1.5ex \@plus -1ex \@minus -.2ex}%
      {1ex \@plus.2ex}{\@headingfont}{#1}%
   \nopagebreak        
}

\renewcommand{\section}[1]{%
   \addtocounter{nsection}{1}
   \@startsection
      {section}{1}{\z@}{-1.5ex \@plus -1ex \@minus -.2ex}%
      {1ex \@plus.2ex}{\@asectionfont\centering}{#1}%
   \nopagebreak        
} 

\newcommand{\writer}[1]{
 \nopagebreak
 \begin{flushright}\textit{#1}\end{flushright}
}

% No section numbers.
 
\setcounter{secnumdepth}{0}

% Other numbering

\def\figurename{Obr. }
\pagenumbering{arabic}
\def\labelitemi{$\m@th\bullet$}

% Set lists tighter, but brought in by 1em (otherwise the first line 
% always looks very wide).  Should this be done with \rightskip?
% It actually does nothing since after this \rightskip is set to
% \@rightskip: I think \rightmargin was intended but should we change
% it now?
 
\renewcommand{\@listI}{%
   \setlength{\leftmargin}{\leftmargini}%
   \setlength{\topsep}{\medskipamount}%
   \setlength{\itemsep}{0pt}%
   \setlength{\listparindent}{1em}%
   \setlength{\rightskip}{1em}%
}
\let \@listi \@listI

% But have a list type with no indentation on either side:
% 
\renewenvironment{description}
               {\list{}{\labelwidth\z@
                   \leftmargin \z@
                   \rightmargin \z@
                   \itemindent-\leftmargin
                   \let\makelabel\descriptionlabel}}
               {\endlist}

\newenvironment{citations}{%
   \list{}{%
      \renewcommand{\makelabel}[1]{\itshape{##1},}%
   }%
}{%
   \endlist
}
 
% Some logos.

\DeclareTextCommand{\clqq}{T1}{\leavevmode\kern.1em
    \char18 \kern-.0158em\nobreak\hskip0pt}
    
  \DeclareTextCommand{\crqq}{T1}
    {{\edef\@SF{\spacefactor\the\spacefactor}%
      \nobreak\kern.06em \char16 \kern.024em \@SF\relax}}
      
\DeclareRobustCommand\uv[1]{{\leavevmode\clqq#1\crqq}}
 
% Hacking to make <...> produce italics in verbatim.  NB: this can be 
% done more cleanly using the verbatim package.  But the Journal class
% has  to run on any LaTeX installation, even those without the
% verbatim package.  
 
% Here we extend the font-setting command to include making <> active
% (ie adjusting the input encoding).
\renewcommand \verbatim@font {%
  \normalfont \ttfamily
  \catcode`\<=\active
  \catcode`\>=\active
}
  
% Make active <...> produce italics surrounded by angle brackets
% (used in verbatim and \verb);
% << produces a less-than, and >> produces a greater-than.
 
\begingroup
  \catcode`\<=\active
  \catcode`\>=\active
  \gdef<{\@ifnextchar<\@lt\@meta}
  \gdef>{\@ifnextchar>\@gt\@gtr@err}
  \gdef\@meta#1>{{\reset@font\normalsize\itshape#1\/}}
  \gdef\@lt<{\char`\<}
  \gdef\@gt>{\char`\>}
\endgroup
\def\@gtr@err{%
   \ClassError{ltxguide}{%
      Isolated \protect>%
   }{%
      In this document class, \protect<...\protect>
      is used to indicate a parameter.\MessageBreak
      I've just found a \protect> on its own.
      Perhaps you meant to type \protect>\protect>?
   }%
}
\def\verbatim@nolig@list{\do\`\do\,\do\'\do\-}

% degree, angle, tg, g definitions

\font\symbs=msam10
\def\angle{\mbox{\symbs\char94}}
\def\degree{^{\circ}}
\def\Degree{\(^{\circ}\)}
\def\tg{\qopname\relax{no}{tg}}
\def\g#1{\mathbf{#1}}
\def\G#1{\(\mathbf{#1}\)}

% That's it!
 
\endinput
 
% Changes
% ------------------------------------------------------
% 1.0 - first release, derivated from the "ltnews" class
% 2.0 - second major release, universal