/***********************************************************************

  ColorBox2: cb2jit.cpp
    (c) 2004 by Martin Decky
  
  Distributed under the terms of Lesser General Public Licence, see
  COPYING.

  0.3			10th August 2004	initial

***********************************************************************/


#include <iostream>
#include <string>
#include <utils.h>
#include "cb2jit.h"
#include "make.h"


using namespace CB2;
using namespace std;


void usage(const char * name) {
	cout << endl
	     << "ColorBox2 Just-In-Time Compiler" << endl
	     << endl
	     << "Command-line syntax:" << endl
	     << " " << name << " <source tree> <binary tree> <binary file>" << endl
	     << endl
	     << "  source tree - root of the tree of souces" << endl
	     << "  binary tree - root of the tree of binaries" << endl
	     << "  binary file - name of the binary file to generate" << endl
	     << endl;
}


void split_path(const String & filename, String & path, String & file) {
	path = "";
	file = "";
	
	StringTokenizer tok(filename, "/");
	String prev;
	bool first = true;

	for (StringTokenizer::iterator it = tok.Begin(); it != tok.End(); ++it) {
		if (first)
			first = false;
		else {
			path += prev;
			path += "/";
		}
			
		prev = *it;
		file = *it;
	}
	
}


int main(int argc, char * argv[]) {
	if (argc < 4) { /* Not enought parameters */
		/* Print usage and exit */
		usage(argv[0]);
		return 1;
	}
	
	String src_path = argv[1];
	String bin_path = argv[2];
	String bin_file = argv[3];
	
	String path;
	String file;
	
	/* Extract binary file path
	   components */
	split_path(bin_file, path, file);
	
	/* Change directory */
	if (chdir(src_path + String("/") + path) != 0) {
		cerr << "Unable to change directory" << endl;
		return 2;
	}
	
	/* Execute make */
	return make(bin_path + String("/") + file, bin_path);
}
