/***********************************************************************

  ColorBox2: mod_cb2.h
    (c) 2004 by Martin Decky
  
  Distributed under the terms of Lesser General Public Licence, see
  COPYING.

  0.1			13th June 2003		initial
  0.2			20th June 2003		forking and binary running
  0.3			10th August 2004	cleanup, documentation

***********************************************************************/


#ifndef __MOD_CB2_H__
#define __MOD_CB2_H__


#include "httpd.h"
#include "http_config.h"
#include "http_conf_globals.h"
#include "http_core.h"
#include "http_log.h"
#include "http_main.h"
#include "http_protocol.h"
#include "util_script.h"


/** Some global defines
 *
 */
#define MODULE_NAME "mod_cb2"
#define BUFFER_SIZE 102400
#define BUFFER_BYTES (sizeof(char) * BUFFER_SIZE)


/** Standard boolean values
 *
 */
#define false 0
#define true 1


typedef int bool_t; /**< Boolean type alias */


/** Configuration scope type
 *
 * Defines the scope of a given configuration
 * (directory specific, server-wide, etc.).
 *
 */
enum config_mode_t {
	cm_server,    /**< Server-wide configuration */
	cm_directory, /**< Directory configuration */
	cm_combo      /**< Combined configuration */
};


/** General warning type
 *
 * Defines the kind of a warning
 * on a general level
 *
 */
enum warn_t {
	warn_int,
	warn_runtime,
	warn_perm,
	warn_exec,
	warn_io
};


/** I/O status/warning type
 *
 * Defines the status of an I/O operation,
 * permission check and kind of I/O warning.
 *
 */
enum io_status_t {
	io_ok = 0,
	io_owned,
	io_wrtbl,
	io_wwrtbl,
	io_notfound,
	io_cantstat,
	io_cantopen,
	io_read,
	io_exec
};


/** Multistate return value type.
 *
 * Defines the return code of a child process.
 *
 */
enum ret_t {
	ret_ok = 0,
	ret_io = -1,
	ret_exec = -2
};


/** Module configuration
 *
 * Structure holding module configuration.
 *
 */
struct excfg_t {
	char * loc; /**< Scope of the configuration */

	enum config_mode_t cmode;  /**< Context of the configuration */
	int compile;               /**< Just-In-Time compilation enabled flag */
	int inherited;             /**< Compile flag is inherited */
	int verbose;               /**< Verbose error messages flag */
	
	const char * binpath;  /**< Binaries tree path */
	const char * srcpath;  /**< Sources tree path */
	const char * jit;      /**< Just-In-Time compiler path */
};


#endif
